The Linux Kernel Mailing List
 help / color / mirror / Atom feed
From: Freeman Yuan <freemanyuan15@gmail.com>
To: Greg Kroah-Hartman <gregkh@linuxfoundation.org>
Cc: linux-kernel@vger.kernel.org, Freeman Yuan <freemanyuan15@gmail.com>
Subject: [PATCH] staging: rtl8723bs: fix cmdThread CamelCase style warning
Date: Thu,  9 Jul 2026 19:13:46 -0700	[thread overview]
Message-ID: <20260710021346.402-1-freemanyuan15@gmail.com> (raw)

Rename the CamelCase variable structure member cmdThread to cmd_thread
inside drv_types.h and rtw_cmd.c to align with standard Linux kernel
coding style guidelines.

Signed-off-by: Freeman Yuan <freemanyuan15@gmail.com>
---
--- a/drivers/staging/rtl8723bs/include/drv_types.h	2026-07-05 12:48:26.445848305 -0700
+++ b/drivers/staging/rtl8723bs/include/drv_types.h	2026-07-05 12:43:05.869520819 -0700
@@ -307,7 +307,7 @@
 	u8 init_adpt_in_progress;
 	u8 bHaltInProgress;
 
-	void *cmdThread;
+	void *cmd_thread;
 	void *evtThread;
 	void *xmitThread;
 	void *recvThread;
--- a/drivers/staging/rtl8723bs/core/rtw_cmd.c	2026-07-05 12:48:26.463848308 -0700
+++ b/drivers/staging/rtl8723bs/core/rtw_cmd.c	2026-07-05 12:43:05.867520813 -0700
@@ -156,14 +156,14 @@
 };
 
 /*
  * Caller and the rtw_cmdThread can protect cmd_q by spin_lock.
  * No irqsave is necessary.
  */
 
 int rtw_init_cmd_priv(struct	cmd_priv *pcmdpriv)
 {
 	init_completion(&pcmdpriv->cmd_queue_comp);
-	init_completion(&pcmdpriv->terminate_cmdThread_comp);
+	init_completion(&pcmdpriv->terminate_cmd_thread_comp);
 
 	INIT_LIST_HEAD(&pcmdpriv->cmd_queue.queue);
 	spin_lock_init(&pcmdpriv->cmd_queue.lock);
@@ -361,18 +361,18 @@
 	kfree(pcmd);
 }
 
-void rtw_stop_cmdThread(struct adapter *adapter)
+void rtw_stop_cmd_thread(struct adapter *adapter)
 {
-	if (adapter->cmdThread &&
+	if (adapter->cmd_thread &&
 	    atomic_read(&adapter->cmdpriv.cmdthd_running) &&
 		adapter->cmdpriv.stop_req == 0) {
 		adapter->cmdpriv.stop_req = 1;
 		complete(&adapter->cmdpriv.cmd_queue_comp);
-		wait_for_completion(&adapter->cmdpriv.terminate_cmdThread_comp);
+		wait_for_completion(&adapter->cmdpriv.terminate_cmd_thread_comp);
 	}
 }
 
-int rtw_cmdThread(void *context)
+int rtw_cmd_thread(void *context)
 {
 	u8 ret;
 	struct cmd_obj *pcmd;
@@ -389,7 +389,7 @@
 
 	pcmdpriv->stop_req = 0;
 	atomic_set(&pcmdpriv->cmdthd_running, true);
-	complete(&pcmdpriv->terminate_cmdThread_comp);
+	complete(&pcmdpriv->terminate_cmd_thread_comp);
 
 	while (1) {
 		if (wait_for_completion_interruptible(&pcmdpriv->cmd_queue_comp)) {
@@ -511,7 +511,7 @@
 		rtw_free_cmd_obj(pcmd);
 	} while (1);
 
-	complete(&pcmdpriv->terminate_cmdThread_comp);
+	complete(&pcmdpriv->terminate_cmd_thread_comp);
 	atomic_set(&pcmdpriv->cmdthd_running, false);
 
 	return 0;
@@ -1733,7 +1733,7 @@
 			rtw_hal_c2h_handler(adapter, c2h_evt);
 			kfree(c2h_evt);
 		} else {
 			/* Enqueue into cmdThread for others */
 			rtw_c2h_wk_cmd(adapter, c2h_evt);
 		}
 	}
@@ -156,14 +156,14 @@
 
 /*
- * Caller and the rtw_cmdThread can protect cmd_q by spin_lock.
+ * Caller and the rtw_cmd_thread can protect cmd_q by spin_lock.
  * No irqsave is necessary.
  */
@@ -1733,7 +1733,7 @@
 			kfree(c2h_evt);
 		} else {
-			/* Enqueue into cmdThread for others */
+			/* Enqueue into cmd_thread for others */
 			rtw_c2h_wk_cmd(adapter, c2h_evt);
 		}

             reply	other threads:[~2026-07-10  2:13 UTC|newest]

Thread overview: 6+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2026-07-10  2:13 Freeman Yuan [this message]
  -- strict thread matches above, loose matches on Subject: below --
2026-07-06  0:44 [PATCH] staging: rtl8723bs: fix cmdThread CamelCase style warning Freeman Yuan
2026-07-05 19:48 Freeman Yuan
2026-07-06  5:18 ` Greg KH
2026-07-04  3:41 Freeman Yuan
2026-07-04  6:40 ` Greg KH

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20260710021346.402-1-freemanyuan15@gmail.com \
    --to=freemanyuan15@gmail.com \
    --cc=gregkh@linuxfoundation.org \
    --cc=linux-kernel@vger.kernel.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox